
#ifndef LIBKGAPI2_EXPORT_H
#define LIBKGAPI2_EXPORT_H

#ifdef LIBKGAPI2_STATIC_DEFINE
#  define LIBKGAPI2_EXPORT
#  define LIBKGAPI2_NO_EXPORT
#else
#  ifndef LIBKGAPI2_EXPORT
#    ifdef MAKE_KGAPI2_LIB
        /* We are building this library */
#      define LIBKGAPI2_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LIBKGAPI2_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBKGAPI2_NO_EXPORT
#    define LIBKGAPI2_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBKGAPI2_DEPRECATED
#  define LIBKGAPI2_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBKGAPI2_DEPRECATED_EXPORT
#  define LIBKGAPI2_DEPRECATED_EXPORT LIBKGAPI2_EXPORT LIBKGAPI2_DEPRECATED
#endif

#ifndef LIBKGAPI2_DEPRECATED_NO_EXPORT
#  define LIBKGAPI2_DEPRECATED_NO_EXPORT LIBKGAPI2_NO_EXPORT LIBKGAPI2_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKGAPI2_NO_DEPRECATED
#    define LIBKGAPI2_NO_DEPRECATED
#  endif
#endif

#endif /* LIBKGAPI2_EXPORT_H */
